==> haskell-parsers-0.12.5-6-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-parsers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: parsers
version: 0.12.5
id: parsers-0.12.5-FBiee1ATP2DJ3uofdpH32r
key: parsers-0.12.5-FBiee1ATP2DJ3uofdpH32r
license: BSD3
copyright: Copyright (C) 2010-2013 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: experimental
homepage: http://github.com/ekmett/parsers/
synopsis: Parsing combinators
description:
    This library provides convenient combinators for working with and building parsing combinator libraries.
    .
    Given a few simple instances, e.g. for the class '\''Text.Parser.Combinators.Parsing'\'' in "Text.Parser.Combinators.Parsing" you
    get access to a large number of canned definitions. Instances exist for the parsers provided by @parsec@,
    @attoparsec@ and base’s "Text.Read".
category: Text, Parsing
author: Edward A. Kmett
exposed: True
exposed-modules:
    Text.Parser.Char Text.Parser.Combinators Text.Parser.LookAhead
    Text.Parser.Permutation Text.Parser.Expression Text.Parser.Token
    Text.Parser.Token.Style Text.Parser.Token.Highlight
abi: 7b7b0739ebf82c8a30fb005bd4baf553
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/parsers-0.12.5
library-dirs: /usr/lib/ghc-8.0.2/site-local/parsers-0.12.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.0.2/parsers-0.12.5
hs-libraries: HSparsers-0.12.5-FBiee1ATP2DJ3uofdpH32r
depends:
    attoparsec-0.13.1.0-DWdB5NAuEI54zL0UJYXwyo base-4.9.1.0
    base-orphans-0.6-AbJ3lKVXygDCG0eeQEv8Iu
    charset-0.3.7.1-ExxkLwSUKUPEceMD96Skef containers-0.5.7.1
    mtl-2.2.1-BLKBelFsPB3BoFeSWSOYj6
    parsec-3.1.11-1CA7c0vSU7tJHGhveOjoXR
    scientific-0.3.5.0-7hRLtQzMvnkCQbsJuyPHcq
    text-1.2.2.2-3ENqlljngKa6xj1Go2fVWq transformers-0.5.2.0
    unordered-containers-0.2.8.0-1tqMF698WJE3INvmpuzQZc
haddock-interfaces: /usr/share/doc/haskell-parsers/html/parsers.haddock
haddock-html: /usr/share/doc/haskell-parsers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-parsers-0.12.5-8-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-parsers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: parsers
version: 0.12.5
id: parsers-0.12.5-AXzq17gNTfCKs6hv5mWVL8
key: parsers-0.12.5-AXzq17gNTfCKs6hv5mWVL8
license: BSD3
copyright: Copyright (C) 2010-2013 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: experimental
homepage: http://github.com/ekmett/parsers/
synopsis: Parsing combinators
description:
    This library provides convenient combinators for working with and building parsing combinator libraries.
    .
    Given a few simple instances, e.g. for the class '\''Text.Parser.Combinators.Parsing'\'' in "Text.Parser.Combinators.Parsing" you
    get access to a large number of canned definitions. Instances exist for the parsers provided by @parsec@,
    @attoparsec@ and base’s "Text.Read".
category: Text, Parsing
author: Edward A. Kmett
exposed: True
exposed-modules:
    Text.Parser.Char Text.Parser.Combinators Text.Parser.LookAhead
    Text.Parser.Permutation Text.Parser.Expression Text.Parser.Token
    Text.Parser.Token.Style Text.Parser.Token.Highlight
abi: b221d7d2142020f1cbdb0d2327973b75
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/parsers-0.12.5
library-dirs: /usr/lib/ghc-8.0.2/site-local/parsers-0.12.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.0.2/parsers-0.12.5
hs-libraries: HSparsers-0.12.5-AXzq17gNTfCKs6hv5mWVL8
depends:
    attoparsec-0.13.1.0-7xLJO1EwFQpJLBzOR8WqkC base-4.9.1.0
    base-orphans-0.6-AbJ3lKVXygDCG0eeQEv8Iu
    charset-0.3.7.1-ExxkLwSUKUPEceMD96Skef containers-0.5.7.1
    mtl-2.2.1-BLKBelFsPB3BoFeSWSOYj6
    parsec-3.1.11-1CA7c0vSU7tJHGhveOjoXR
    scientific-0.3.5.1-3aJEdQvcyho88FhIoGrzGS
    text-1.2.2.2-3ENqlljngKa6xj1Go2fVWq transformers-0.5.2.0
    unordered-containers-0.2.8.0-1tqMF698WJE3INvmpuzQZc
haddock-interfaces: /usr/share/doc/haskell-parsers/html/parsers.haddock
haddock-html: /usr/share/doc/haskell-parsers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
